@@ -3,11 +3,20 @@ from ..util import Model
 
 class Group(Model):
 	def __init__(self):
+		self.__group_operator = None
 		self.__comparator = None
 		self.__field = None
 		self.__value = None
+		self.__group = None
 		self.__key_modified = dict()
 
+	def get_group_operator(self):
+		return self.__group_operator
+
+	def set_group_operator(self, group_operator):
+		self.__group_operator = group_operator
+		self.__key_modified["group_operator"] = 1
+
 	def get_comparator(self):
 		return self.__comparator
 
@@ -29,6 +38,13 @@ class Group(Model):
 		self.__value = value
 		self.__key_modified["value"] = 1
 
+	def get_group(self):
+		return self.__group
+
+	def set_group(self, group):
+		self.__group = group
+		self.__key_modified["group"] = 1
+
 	def is_key_modified(self, key):
 		return self.__key_modified.get(key)
 
